---
title: <span class="badge object-type-scalar"></span> MebibytesPerSecond
---
# <span class="badge object-type-scalar"></span> MebibytesPerSecond

Data rate: mebibytes/sec

## Definition

```python
# Data rate: mebibytes/sec
MebibytesPerSecond: typing.Literal["MiBs"] = "MiBs"
```
